@@ -34,7 +34,7 @@ extern "C"
   typedef unsigned int uint32;
   typedef unsigned char uint8;
 
-#define NTLM_VERSION "0.3.9"
+#define NTLM_VERSION "0.3.10"
 
 /*
  * These structures are byte-order dependant, and should not
@@ -122,6 +122,16 @@ extern "C"
 					const char *user,
 					const char *password);
 
+  /* smbencrypt.c */
+  extern void
+  ntlm_smb_encrypt (const char *passwd,
+		    const uint8 * challenge,
+		    uint8 * answer);
+  extern void
+  ntlm_smb_nt_encrypt (const char *passwd,
+		       const uint8 * challenge,
+		       uint8 * answer);
+
   extern const char *ntlm_check_version (const char *req_version);
 
 # ifdef __cplusplus
